==> zio-aws-ec2_2.12-7.21.15.7-sources.jar: zio/aws/ec2/model/RequestSpotFleetRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RequestSpotFleetRequest(
    dryRun: Optional[Boolean] = Optional.Absent,
    spotFleetRequestConfig: zio.aws.ec2.model.SpotFleetRequestConfigData
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest = {
    import RequestSpotFleetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .spotFleetRequestConfig(spotFleetRequestConfig.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.RequestSpotFleetRequest.ReadOnly =
    zio.aws.ec2.model.RequestSpotFleetRequest.wrap(buildAwsValue())
}
object RequestSpotFleetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.RequestSpotFleetRequest =
      zio.aws.ec2.model.RequestSpotFleetRequest(
        dryRun.map(value => value),
        spotFleetRequestConfig.asEditable
      )
    def dryRun: Optional[Boolean]
    def spotFleetRequestConfig
        : zio.aws.ec2.model.SpotFleetRequestConfigData.ReadOnly
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
    def getSpotFleetRequestConfig: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.SpotFleetRequestConfigData.ReadOnly
    ] = ZIO.succeed(spotFleetRequestConfig)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
  ) extends zio.aws.ec2.model.RequestSpotFleetRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
    override val spotFleetRequestConfig
        : zio.aws.ec2.model.SpotFleetRequestConfigData.ReadOnly =
      zio.aws.ec2.model.SpotFleetRequestConfigData
        .wrap(impl.spotFleetRequestConfig())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
  ): zio.aws.ec2.model.RequestSpotFleetRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.17.1-sources.jar: zio/aws/ec2/model/RequestSpotFleetRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class RequestSpotFleetRequest(
    spotFleetRequestConfig: zio.aws.ec2.model.SpotFleetRequestConfigData
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest = {
    import RequestSpotFleetRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
      .builder()
      .spotFleetRequestConfig(spotFleetRequestConfig.buildAwsValue())
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.RequestSpotFleetRequest.ReadOnly =
    zio.aws.ec2.model.RequestSpotFleetRequest.wrap(buildAwsValue())
}
object RequestSpotFleetRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.RequestSpotFleetRequest =
      zio.aws.ec2.model
        .RequestSpotFleetRequest(spotFleetRequestConfig.asEditable)
    def spotFleetRequestConfig
        : zio.aws.ec2.model.SpotFleetRequestConfigData.ReadOnly
    def getSpotFleetRequestConfig: ZIO[
      Any,
      Nothing,
      zio.aws.ec2.model.SpotFleetRequestConfigData.ReadOnly
    ] = ZIO.succeed(spotFleetRequestConfig)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
  ) extends zio.aws.ec2.model.RequestSpotFleetRequest.ReadOnly {
    override val spotFleetRequestConfig
        : zio.aws.ec2.model.SpotFleetRequestConfigData.ReadOnly =
      zio.aws.ec2.model.SpotFleetRequestConfigData
        .wrap(impl.spotFleetRequestConfig())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.RequestSpotFleetRequest
  ): zio.aws.ec2.model.RequestSpotFleetRequest.ReadOnly = new Wrapper(impl)
}
